==> haskell-simple-sendfile-0.2.30-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-sendfile
version:              0.2.30
visibility:           public
id:                   simple-sendfile-0.2.30-I4rdONWk3eeHpu3ytCvWYn
key:                  simple-sendfile-0.2.30-I4rdONWk3eeHpu3ytCvWYn
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  20bfe33087ac070baef1303da4cf9f9d
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-8.10.4/site-local/simple-sendfile-0.2.30
library-dirs:         /usr/lib/ghc-8.10.4/site-local/simple-sendfile-0.2.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/simple-sendfile-0.2.30
hs-libraries:         HSsimple-sendfile-0.2.30-I4rdONWk3eeHpu3ytCvWYn
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    network-3.1.2.1-3J2farqahIBByMpQGhmaOp unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.30-174-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-sendfile
version:              0.2.30
visibility:           public
id:                   simple-sendfile-0.2.30-2hayoWvXXZTBf42IizFq6D
key:                  simple-sendfile-0.2.30-2hayoWvXXZTBf42IizFq6D
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  801cb7470bf2789d2b9e5a1972d9acf7
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-8.10.4/site-local/simple-sendfile-0.2.30
library-dirs:         /usr/lib/ghc-8.10.4/site-local/simple-sendfile-0.2.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/simple-sendfile-0.2.30
hs-libraries:         HSsimple-sendfile-0.2.30-2hayoWvXXZTBf42IizFq6D
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    network-3.1.2.1-FFPh7xoS2oFG4R5fZE4ulG unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
